quscope.image\_processing
=========================

.. automodule:: quscope.image_processing

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   filtering
   preprocessing
   quantum_encoding
   quantum_segmentation
